.. proFit documentation master file, created by
   sphinx-quickstart on Wed May 29 14:25:05 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to proFit's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   proFit <README>
   config
   cluster
   ui
   CONTRIBUTING


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
